---
title: <span class="badge object-type-scalar"></span> Kilogram
---
# <span class="badge object-type-scalar"></span> Kilogram

Mass: kilogram (kg)

## Definition

```python
# Mass: kilogram (kg)
Kilogram: typing.Literal["masskg"] = "masskg"
```
